import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { ApiQuery, ApiResponse, ApiTags } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { BaseController } from 'free-midway-component';
import { TestService } from '../service/test.service';
import { CreateDTO_test, CreateVO_test, FetchVO_test, QueryDTO_test, QueryVO_test, UpdateDTO_test, UpdateVO_test } from '../interface/test.interface';

@ApiTags(['测试表索引'])
@Controller('/test')
export class TestController extends BaseController {
  @Inject()
  service: TestService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CreateVO_test })
  async create(@Body() data: CreateDTO_test) {
    const result = await this.service.create(data);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QueryVO_test })
  async query(@Query() filter: QueryDTO_test, @Query('skip') skip: number, @Query('limit') limit: number) {
    const data = await this.service.query(filter, { skip, limit, sort: { 'meta.createdAt': -1 } });
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FetchVO_test })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FetchVO_test(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UpdateVO_test })
  async update(@Param('id') id: string, @Body() body: UpdateDTO_test) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
